@@ -18,6 +18,7 @@ import manageprojects
 from manageprojects import __version__
 from manageprojects.cookiecutter_templates import (
     clone_managed_project,
+    reverse_managed_project,
     start_managed_project,
     update_managed_project,
 )
@@ -266,6 +267,21 @@ def clone_project(
     )
 
 
+@app.command()
+def reverse(
+    project_path: Path,
+    destination: Path,
+):
+    """
+    Create a cookiecutter template from a managed project.
+    """
+    log_config()
+    return reverse_managed_project(
+        project_path=project_path,
+        destination=destination,
+    )
+
+
 @app.command()
 def wiggle(project_path: Path, words: bool = False):
     """
